/* =============================================================================
 *
 *            TEXAS INSTRUMENTS INCORPORATED PROPRIETARY INFORMATION
 *
 *  Property of Texas Instruments
 *  For Unrestricted Internal Use Only 
 *  Unauthorized reproduction and/or distribution is strictly
 *  prohibited.
 *  This product is protected under copyright law and trade secret law  
 *  as an unpublished work.
 *  Created 2003, (C) Copyright 2003 Texas Instruments.  All rights 
 *  reserved.
 */
/**
 *  @Component                  PCT_PADTEST_TC
 *
 *  @Filename                   PCT_PADTEST_TC.h
 *
 *  @Description                Primary test case header file for this component
 *                              <Add multiple line description of test case here>
 *
 *  Min HW modules required:    <add minimum HW modules required to run test>
 *
 *  Conditional compilation:    <add conditional compile opitons here>
 *   
 *  Domain(s) tested:           <add domain test here>
 *
 *//*======================================================================== */
#ifndef __PCT_PADTEST_TC_H
#define __PCT_PADTEST_TC_H


#ifdef __cplusplus
extern "C"
{
#endif

/* ============================================================================
* INCLUDE FILES (only if necessary)
* =============================================================================
*/

/* trm_global_types.h defines customized and key C types - unsigned long int  , etc.*/

#include "trm_global_types.h"




/* ============================================================================
*  DEFINITIONS
* =============================================================================
*/


/*The pad configuration HEADER exported from PCT tool should be inserted below*/
 
 #include "PCT_exported_settings.h"
 
 
 
 /* Customer should define number of pads configured in PCT tool*/ 
 
 #define NUM_OF_PADS  6
 
 
 /* Customer should specify the list of pads already adjusted by PCT tool (their original names) in below format */
  
 #define PAD_ARRAY { PAD_abe_mcbsp2_clkx,PAD_abe_mcbsp2_fsx,PAD_i2c3_scl,PAD_i2c4_sda,PAD_dpm_emu16,PAD_dpm_emu19 }


/* ============================================================================
* EXPORTED TYPES
* =============================================================================
*/

/* 
   The below global structure type defines field variables to store PCT TOOL extracted header settings 
   It is aligned with PCT tool output header format.
   
   
   ******************************************************************************************************
   Field #1:  pad_name string 
   Field #2:  HEX base address of the OMAP4470 ES1.0 Control Module instance in which pad registers reside
   
   *******************************************************************************************************
   
   ======================================================================================================
   *******Padconf registers fields - CONTROL_CORE_PAD0_X_PAD1_Y / CONTROL_WKUP_PAD0_X_PAD1_Y ************
   
  
   Field #3:  HEX value of the offset address of the corresponding 16-bit padconfiguration  register   
              Note that "Padconf" registers are  register of type CONTROL_CORE_PAD0_X_PAD1_Y  
	      or CONTROL_WKUP_PAD0_X_PAD1_Y  
   
   Field #4:  16bit HEX value set in padconf register by PCT tool
   
   ======================================================================================================
   
    ===========================================================================================================
    ****************************Additional PAD functionality setting related registers  ***********************
    
    Up to 10 additional registers are considered, though actual number of these registers per pad may not reach 10 
   
    Field #5:  HEX value of the offset address of the 32 bit Register1  
    Field #6:  32-bit HEX value - the one set in PCT 
    Field #7:  32-bit MASK HEX value extracted from PCT to provide that only bits of interest are modified 
   
    Field #8,#9,#10: Same descriptions as for Field #5,#6,#7 but relevant for the 32 bit Register2 
    .
    .
    .
    .
    Field #32,#33,#34 : Same descriptions as for Field #5,#6,#7 but relevant for the 32 bit Register10 
    ===========================================================================================================

*/


 
typedef struct PADCONF_padInfo_t_label 

{
  char  pad_name[80];
  
  u32   BaseAddr;
  
  s16   Padconf_OffsetAddr; /* the s32 type - allows signed value Padconf_OffsetAddr = -1 */
                          /* which means padconf register is not available for pad */
                          
  u16   Padconf_Value;
  
  u32   Reg1_OffsetAddr;
  u32   Reg1_Value;
  u32   Reg1_Mask;
  
  u32   Reg2_OffsetAddr;
  u32   Reg2_Value;
  u32   Reg2_Mask;
  
  u32   Reg3_OffsetAddr;
  u32   Reg3_Value;
  u32   Reg3_Mask;
  
  u32   Reg4_OffsetAddr;
  u32   Reg4_Value;
  u32   Reg4_Mask;
  
  u32   Reg5_OffsetAddr;
  u32   Reg5_Value;
  u32   Reg5_Mask;
  
  u32   Reg6_OffsetAddr;
  u32   Reg6_Value;
  u32   Reg6_Mask;
  
  u32   Reg7_OffsetAddr;
  u32   Reg7_Value;
  u32   Reg7_Mask;
  
  u32   Reg8_OffsetAddr;
  u32   Reg8_Value;
  u32   Reg8_Mask;
  
  u32   Reg9_OffsetAddr;
  u32   Reg9_Value;
  u32   Reg9_Mask;
  
  u32   Reg10_OffsetAddr;
  u32   Reg10_Value;
  u32   Reg10_Mask;
  
} PADCONF_padInfo_t ;

 

extern int Pad_Regs_Write (PADCONF_padInfo_t *);
/* ============================================================================
* EXPORTED VARIABLES
* =============================================================================
*/

/* ============================================================================
* EXPORTED FUNCTIONS
* =============================================================================
*/

/* ------------------------------------------------------------------------*//**
 * @FUNCTION    PCT_PADTEST_TC_TestFunction
 *
 * @BRIEF       Primary test function
 *
 * @RETURN      RET_OK              No errors occured
 *              <add your return codes here>
 *
 * @PURPOSE     This Primary test funciton for <add component name here> test case
 *
 * @METHOD      <add highlevel test case method here, this field is optional
 *              if not using then remove METHOD field completely>
 * 
 *//*------------------------------------------------------------------------ */

extern ReturnCode_t PCT_PADTEST_TC_TestFunction(void);




#ifdef __cplusplus
}
#endif
#endif	/* __PCT_PADTEST_TC_H */

/* EOF */


